> **Please do not create a pull request without creating an issue first.**
>
> Changes need to be discussed before proceeding, pull requests submitted without linked issues may be rejected.
>
> Please provide enough information so that others can review your pull request. You can skip this if you're fixing a typo – it happens.
>
> **Please remove this indented content before submitting your issue.**

* [ ] I have added tests to `tests` to cover my changes.
* [ ] I have added `docs/`, if necessary.
* [ ] I have updated the `README.md`, if necessary.
* [ ] I have updated the `CONTRIBUTING.md`, if necessary.

## What issue does this pull request close?

Put `Closes #issue-number` here to auto-close the issue.

## How are these changes tested?

This pull request includes automated tests for the code it touches and those tests are described below.

These changes are tested with [...]

## Demonstration

For example, what are the exact commands another person has to run and the output they would expect to see, related screenshots, screen-recordings, test runs, et cetera.

## Provide additional context.

Provide as much relevant context as you like.
